Module backend

Module backend 

CPU framebuffer backend implementing oxiui_core::paint::RenderBackend. SoftBackend: a oxiui_core::paint::RenderBackend implementation that replays a oxiui_core::paint::DrawList onto a CPU Framebuffer through a single Canvas.

Because all commands share one Canvas for the entire oxiui_core::paint::RenderBackend::execute call, PushClip/PopClip commands are correctly applied to every subsequent draw command — there is no clip-leak between commands.

Structs

SoftBackend
CPU framebuffer backend implementing oxiui_core::paint::RenderBackend.

Functions

blit_glyph_bitmap
Blit a greyscale alpha-coverage bitmap into the canvas at (origin_x, origin_y), tinting each pixel with color.