Module draw

Module draw 

Drawing primitives: rectangles, lines, circles, rounded rects, blits. Drawing primitives operating on a Framebuffer through a clip stack.

Canvas borrows a framebuffer and owns a ClipStack; all drawing is clipped to the current effective clip. Shapes use straight-alpha source-over compositing; circles and rounded rectangles use analytical coverage-based anti-aliasing along their edges.

Structs

Canvas
A clipped drawing surface over a Framebuffer.
DashPattern
Dash pattern for Canvas::draw_line_dashed.
SrcImage
A borrowed RGBA source image for Canvas::blit_rgba.