pub struct RadialGradient {
pub center: (f32, f32),
pub radius: f32,
pub stops: Vec<GradientStop>,
}Expand description
A radial gradient defined by a centre point, a radius, and colour stops.
The gradient transitions from stops[0] at the centre to stops[-1] at
the edge of the circle. Beyond the radius the last stop colour is used.
Fields
center: (f32, f32)Centre of the gradient circle (logical pixels).
radius: f32Radius of the gradient circle (logical pixels).
stops: Vec<GradientStop>Colour stops, sorted by ascending offset (0.0 = centre, 1.0 = edge).
Implementations
Sourceimpl RadialGradient
impl RadialGradient
Sourcepub fn two_stop(
center: (f32, f32),
radius: f32,
inner: Color,
outer: Color,
) -> Self
pub fn two_stop( center: (f32, f32), radius: f32, inner: Color, outer: Color, ) -> Self
Construct a two-stop radial gradient from inner at the centre to
outer at the edge.
Sourcepub fn new(center: (f32, f32), radius: f32, stops: Vec<GradientStop>) -> Self
pub fn new(center: (f32, f32), radius: f32, stops: Vec<GradientStop>) -> Self
Construct from arbitrary stops; they are sorted by offset internally.